#Version of simplyhack
import simplyhack
